@@ -19,7 +19,7 @@ from .response import (
 from .ssl.cert_store import CertStore
 from .util import TimeoutManager
 
-__version__ = '0.1.8'
+__version__ = '0.1.10'
 
 __timeout = TimeoutManager(DEFAULT_REQUEST_TIMEOUT)
 __cert_store = CertStore(DEFAULT_HOSTS_FILE)
@@ -103,7 +103,7 @@ def url(request_url, referer=None):
   return dummy_req.get_url()
 
 
-def request(request_url, referer=None, timeout=None, ca_cert=None):
+def request(request_url, referer=None, timeout=None, raise_errors=False, ca_cert=None):
   '''
   Given a *url* to a Gemini capsule, this performs a request to the specified
   url and returns a response (as a subclass of [ignition.BaseResponse](#ignitionbaseresponse))
@@ -118,6 +118,10 @@ def request(request_url, referer=None, timeout=None, ca_cert=None):
 
   *See `ignition.url()` for details around url construction with a referer.*
 
+  If *raise_errors* is `True` (default value = `False`), then non-protocol errors
+  will bubble up and be raised as an exception instead of returning
+  [ignition.ErrorResponse](#ignitionerrorresponse)
+
   If a *timeout* is provided, this will specify the client timeout (in seconds)
   for this request.  The default is 30 seconds.  See also `ignition.set_default_timeout`
   to change the default timeout.
@@ -142,16 +146,71 @@ def request(request_url, referer=None, timeout=None, ca_cert=None):
     and will return a response of type [ignition.ClientCertRequiredResponse](#ignitionclientcertrequiredresponse).
   * If *no valid response* can be returned, ignition assigns a response type of "0"
     and returns a response of type [ignition.ErrorResponse](#ignitionerrorresponse).
+    Note: if the user specifies `raise_errors=True`, then any errors will bubble up instead of returning
+    this response type.
 
   Parameters:
   * url: `string`
   * referer: `string` (optional)
   * timeout: `float` (optional)
+  * raise_errors: `bool` (optional)
   * ca_cert: `Tuple(cert_file, key_file)` (optional)
 
   Returns: `[ignition.BaseResponse](#ignitionbaseresponse)`
   '''
 
-  req = Request(request_url, cert_store=__cert_store, request_timeout=__timeout.get_timeout(timeout), referer=referer, ca_cert=ca_cert)
+  req = Request(
+    request_url,
+    cert_store=__cert_store,
+    request_timeout=__timeout.get_timeout(timeout),
+    referer=referer,
+    ca_cert=ca_cert,
+    raise_errors=raise_errors,
+  )
 
   return req.send()
+
+
+__all__ = [
+  "set_default_hosts_file",
+  "set_default_timeout",
+  "url",
+  "request",
+  "ClientCertRequiredResponse",
+  "ErrorResponse",
+  "InputResponse",
+  "PermFailureResponse",
+  "RedirectResponse",
+  "SuccessResponse",
+  "TempFailureResponse",
+  "RESPONSE_STATUS_ERROR",
+  "RESPONSE_STATUS_INPUT",
+  "RESPONSE_STATUS_SUCCESS",
+  "RESPONSE_STATUS_REDIRECT",
+  "RESPONSE_STATUS_TEMP_FAILURE",
+  "RESPONSE_STATUS_PERM_FAILURE",
+  "RESPONSE_STATUS_CLIENTCERT_REQUIRED",
+  "RESPONSE_STATUSDETAIL_ERROR_NETWORK",
+  "RESPONSE_STATUSDETAIL_ERROR_DNS",
+  "RESPONSE_STATUSDETAIL_ERROR_HOST",
+  "RESPONSE_STATUSDETAIL_ERROR_TLS",
+  "RESPONSE_STATUSDETAIL_ERROR_PROTOCOL",
+  "RESPONSE_STATUSDETAIL_INPUT",
+  "RESPONSE_STATUSDETAIL_INPUT_SENSITIVE",
+  "RESPONSE_STATUSDETAIL_SUCCESS",
+  "RESPONSE_STATUSDETAIL_REDIRECT_TEMPORARY",
+  "RESPONSE_STATUSDETAIL_REDIRECT_PERMANENT",
+  "RESPONSE_STATUSDETAIL_TEMP_FAILURE",
+  "RESPONSE_STATUSDETAIL_TEMP_FAILURE_UNAVAILABLE",
+  "RESPONSE_STATUSDETAIL_TEMP_FAILURE_CGI",
+  "RESPONSE_STATUSDETAIL_TEMP_FAILURE_PROXY",
+  "RESPONSE_STATUSDETAIL_TEMP_FAILURE_SLOW_DOWN",
+  "RESPONSE_STATUSDETAIL_PERM_FAILURE",
+  "RESPONSE_STATUSDETAIL_PERM_FAILURE_NOT_FOUND",
+  "RESPONSE_STATUSDETAIL_PERM_FAILURE_GONE",
+  "RESPONSE_STATUSDETAIL_PERM_FAILURE_PROXY_REFUSED",
+  "RESPONSE_STATUSDETAIL_PERM_FAILURE_BAD_REQUEST",
+  "RESPONSE_STATUSDETAIL_CLIENTCERT_REQUIRED",
+  "RESPONSE_STATUSDETAIL_CLIENTCERT_REQUIRED_NOT_AUTHORIZED",
+  "RESPONSE_STATUSDETAIL_CLIENTCERT_REQUIRED_NOT_VALID",
+]
