@@ -1,28 +1,28 @@
 '''
 This Source Code Form is subject to the terms of the
 Mozilla Public License, v. 2.0. If a copy of the MPL
-was not distributed with this file, You can obtain one 
+was not distributed with this file, You can obtain one
 at http://mozilla.org/MPL/2.0/.
 '''
 
 import cgi
-import cryptography
 import logging
 
+from cryptography.x509 import Certificate
+
 from .globals import *
-from .ssl.cert_wrapper import CertWrapper
 
 logger = logging.getLogger(__name__)
 
+
 class ResponseFactory:
   '''
   Wrapper class for factory:
   Determines the approriate response type based on response status
   and generates the appropriate response type
   '''
-  
   @classmethod
-  def create(self, url: str, status: str, meta=None, raw_body=None, certificate=None):
+  def create(cls, url: str, status: str, meta=None, raw_body=None, certificate=None):
     '''
     Given a url, status, and response data, generates the appropriate response type
     '''
@@ -38,18 +38,19 @@ class ResponseFactory:
     }
 
     factory_class = factories.get(basic_status_code, None)
-    
+
     if factory_class is None:
       return ErrorResponse(
-        url, 
-        RESPONSE_STATUSDETAIL_ERROR_PROTOCOL, 
+        url,
+        RESPONSE_STATUSDETAIL_ERROR_PROTOCOL,
         f"Invalid response received from the server, status code: {status}",
         None,
         None,
       )
-      
+
     return factory_class(url, status, meta, raw_body, certificate)
 
+
 class BaseResponse:
   '''
   Abstract Base response type that all response types inherit from.
@@ -67,9 +68,9 @@ class BaseResponse:
   status: str
   meta: str
   raw_body: bytes
-  certificate: cryptography.x509.Certificate
+  certificate: Certificate
 
-  def __init__(self, url: str, status: str, meta: str, raw_body: bytes, certificate: cryptography.x509.Certificate):
+  def __init__(self, url: str, status: str, meta: str, raw_body: bytes, certificate: Certificate):
     '''
     Initializes a BaseResponse with the request url, status code, metadata, raw body string, and remote certificate
     '''
@@ -104,6 +105,13 @@ class BaseResponse:
     '''
     return f"{self.status} {self.meta}"
 
+  def __repr__(self):
+    '''
+    A representation of the string for developers
+    '''
+    return f'<ignition.response.{self.__class__.__name__}: {self.status} {self.meta} [from {self.url}]>'
+
+
 class ErrorResponse(BaseResponse):
   '''
   ErrorResponse
@@ -111,7 +119,7 @@ class ErrorResponse(BaseResponse):
   that are outside of the scope of the Gemini protocol.  Included options are:
 
   00: RESPONSE_STATUSDETAIL_ERROR_NETWORK
-  Any errors that occur at the network level, and prevented the client from making any connection 
+  Any errors that occur at the network level, and prevented the client from making any connection
   with external services.
 
   01: RESPONSE_STATUSDETAIL_ERROR_DNS = "01"
@@ -121,20 +129,20 @@ class ErrorResponse(BaseResponse):
   Any errors connecting to the host (timeout, refused, etc.).
 
   03: RESPONSE_STATUSDETAIL_ERROR_TLS
-  Any errors associated with TLS/SSL, including handshake errors, certificate expired errors, 
+  Any errors associated with TLS/SSL, including handshake errors, certificate expired errors,
   and security errors like certificate rejection errors.
 
   04: RESPONSE_STATUSDETAIL_ERROR_PROTOCOL
-  Any errors where a secure message is received from the server, but it does not conform to the 
+  Any errors where a secure message is received from the server, but it does not conform to the
   Gemini protocol requirements and cannot be processed.
   '''
-
   def data(self):
     '''
     Fetch data relevant to the ErrorResponse; in this case the metadata message from the response
     '''
     return self.meta
 
+
 class InputResponse(BaseResponse):
   '''
   InputRequest
@@ -142,11 +150,10 @@ class InputResponse(BaseResponse):
 
   Status codes beginning with 1 are INPUT status codes, meaning that
   the requested resource accepts a line of textual user input.
-  
+
   The user should reissue a request to the url with parameters in the form:
   gemini://hostname/path?query
   '''
-  
   def data(self):
     '''
     Returns the related instructions for the InputResponse.
@@ -154,6 +161,7 @@ class InputResponse(BaseResponse):
     '''
     return self.meta
 
+
 class SuccessResponse(BaseResponse):
   '''
   SuccessResponse
@@ -161,7 +169,6 @@ class SuccessResponse(BaseResponse):
 
   Status codes beginning with 2 are SUCCESS status codes.
   '''
-
   def data(self):
     '''
     Decode the success message body using metadata in the appropriate encoding type
@@ -173,15 +180,19 @@ class SuccessResponse(BaseResponse):
     try:
       return self.raw_body.decode(encoding)
     except LookupError:
-      logger.warn(f"Could not decode response body using invalid encoding {encoding}")
+      logger.warning(f"Could not decode response body using invalid encoding {encoding}")
       return self.raw_body
-  
+    except UnicodeDecodeError:
+      logger.warning(f"Could not decode response body via encoding {encoding}, returning raw data")
+      return self.raw_body
+
   def __str__(self):
     '''
     The string representation of the success message should be header + body
     '''
     return f"{self.status} {self.meta}{CRLF}{self.data()}"
 
+
 class RedirectResponse(BaseResponse):
   '''
   RedirectResponse
@@ -191,13 +202,13 @@ class RedirectResponse(BaseResponse):
 
   The server is redirecting the client to a new location for the requested resource
   '''
-
   def data(self):
     '''
     Returns the new destination for redirection from the server
     '''
     return self.meta
 
+
 class TempFailureResponse(BaseResponse):
   '''
   TempFailureResponse
@@ -207,13 +218,13 @@ class TempFailureResponse(BaseResponse):
 
   The request has failed, but an identical request may success in the future.
   '''
-
   def data(self):
     '''
     Returns the data from the server in the META field, which may provide additional information to the user.
     '''
     return f"{self.status} {self.meta}"
 
+
 class PermFailureResponse(BaseResponse):
   '''
   PermFailureResponse
@@ -223,13 +234,13 @@ class PermFailureResponse(BaseResponse):
 
   The request has failed, identical requests will likely fail in the future.
   '''
-
   def data(self):
     '''
     Returns the data from the server in the META field, which may provide additional information to the user.
     '''
     return f"{self.status} {self.meta}"
 
+
 class ClientCertRequiredResponse(BaseResponse):
   '''
   ClientCertRequiredResponse
@@ -239,7 +250,6 @@ class ClientCertRequiredResponse(BaseResponse):
 
   The request should be retried with a client certificate.
   '''
-
   def data(self):
     '''
     Return additional information from the server on certificate requirements
